@@ -15,16 +15,15 @@ address. The list of telemetry items can be serialized after the fact and loaded
 lengthy discovery process.
 """
 import time
-from typing import Union, Optional, List, Any
+from typing import Union, Optional, List
 
 from .i2c import SupMCUMaster
 from .serial import SupMCUSerialMaster
-from .parsing import parse_telemetry, _format_to_length, parse_command
+from .parsing import parse_telemetry, _format_to_length, parse_command, SIZEOF_HEADER_FOOTER
 from .types import SupMCUTelemetryDefinition, SupMCUModuleDefinition, TelemetryType, \
-    _supmcu_fmt_data_type, _data_type_sizes, TelemetryDataItem, SupMCUCommand
+    TelemetryDataItem, SupMCUCommand
 from ..i2c import I2CMaster
 
-SIZEOF_HEADER_FOOTER = 13
 SIZEOF_COMMAND_DATA = 33
 SUPMCU_VERSION_DEFINITION = SupMCUTelemetryDefinition("Firmware Version", 77, 0, "S")
 SUPMCU_LENGTH_DEFINITION = SupMCUTelemetryDefinition("Length", 2 + SIZEOF_HEADER_FOOTER, 0, "s")
@@ -74,7 +73,7 @@ def get_version_string(master: Union[I2CMaster, SupMCUSerialMaster], address: in
         version = master.request_telemetry(address, TelemetryType.SupMCU, 0).items[0].value
     elif isinstance(master, SupMCUSerialMaster) and cmd_name is not None:
         version = master.send_command(cmd_name, 'SUP:TEL? 0,ASCII')
-    elif isinstance(master, I2CMaster) or isinstance(master, SupMCUSerialMaster):
+    elif isinstance(master, (I2CMaster, SupMCUSerialMaster)):
         raise TypeError("'address' or 'cmd_name' were not supplied, though they were needed")
     else:
         raise TypeError("'master' must either be an 'I2CMaster' or a 'SupMCUSerialMaster'")
@@ -82,7 +81,8 @@ def get_version_string(master: Union[I2CMaster, SupMCUSerialMaster], address: in
     return version
 
 
-def get_values(i2c_master: I2CMaster, address: int, module_cmd_name: str, idx: int, format: str, response_delay: Optional[float] = None) -> List[TelemetryDataItem]:
+def get_values(i2c_master: I2CMaster, address: int, module_cmd_name: str, idx: int, fmt: str, response_delay: Optional[float] = None) \
+        -> List[TelemetryDataItem]:
     """
     Retrieves the current values of the telemetry object that is indicated by the provided index
 
@@ -99,15 +99,18 @@ def get_values(i2c_master: I2CMaster, address: int, module_cmd_name: str, idx: i
         # None was set by the SupMCU master or the passed in variable.
         response_delay = _DEFAULT_RESPONSE_DELAY
     try:
-        size = _format_to_length(format) + SIZEOF_HEADER_FOOTER
+        size = _format_to_length(fmt) + SIZEOF_HEADER_FOOTER
     except ValueError:
         # Size of version string
         size = SUPMCU_VERSION_DEFINITION.telemetry_length
     # size = SIZEOF_HEADER_FOOTER + sum((_data_type_sizes[f] for f in fmt))
     raw_bytes = _write_read_supcmu_i2c(i2c_master, address, f'{module_cmd_name}:TEL? {idx}\n',
-        size, response_delay)
+                                       size, response_delay)
     # raw_bytes = raw_bytes[SIZEOF_HEADER_FOOTER:]
-    vals = parse_telemetry(raw_bytes, SupMCUTelemetryDefinition('', size, idx, format))
+    vals = parse_telemetry(raw_bytes, SupMCUTelemetryDefinition('', size, idx, fmt))
+    if not vals.header.ready:
+        raise ValueError(f'{module_cmd_name}:TEL? {idx} returned a non-ready response.'
+                         f'Try increasing `response_delay` (=={response_delay})')
     return vals.items
 
 
@@ -178,7 +181,7 @@ def request_telemetry_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
                                           SUPMCU_LENGTH_DEFINITION.telemetry_length, response_delay)
     if is_simulatable_mod:
         simulatable_bytes = _write_read_supcmu_i2c(i2c_master, address, f'{module_cmd_name}:TEL? {idx},SIMULATABLE\n',
-                                                  SUPMCU_LENGTH_DEFINITION.telemetry_length, response_delay)
+                                                   SUPMCU_LENGTH_DEFINITION.telemetry_length, response_delay)
     # Parse the response bytes as telemetry items, then check to see if any are not ready yet
     format_response = parse_telemetry(format_bytes, SUPMCU_FORMAT_DEFINITION)
     name_response = parse_telemetry(name_bytes, SUPMCU_NAME_DEFINITION)
@@ -271,7 +274,7 @@ def request_module_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
     module_defs = {}
     for idx in range(module_amount):
         module_defs[idx] = request_telemetry_definition(i2c_master, address, module_cmd_name, idx, response_delay, is_simulatable_mod)
-        
+
     # Grab the amount of commands on the module, then start requesting ALL command names.
     amount_cmd_resp = _write_read_supcmu_i2c(i2c_master,
                                              address,
@@ -328,4 +331,3 @@ def request_command_name(i2c_master: Union[I2CMaster, SupMCUMaster],
             f'`{module_cmd_name}:COM? {idx}` returned a non-ready response. Try increasing `response_delay`.')
 
     return SupMCUCommand(name_response.command_name, idx)
-
