@@ -18,7 +18,7 @@ for single telemetry items or :func:`~pumpkin_supmcu.request_module_definition`
 import time
 from typing import Optional, Iterable, Union, Dict
 
-from .parsing import parse_telemetry
+from .parsing import parse_telemetry, _format_to_length, SIZEOF_HEADER_FOOTER
 from .types import SupMCUModuleDefinition, SupMCUTelemetry, TelemetryType
 from ..i2c import I2CMaster
 
@@ -156,9 +156,15 @@ class SupMCUMaster:
         except IndexError:
             raise ValueError(f"No definition found for corresponding `{cmd_str}:TEL? {idx}` command.")
 
+        # bug in the bus definition json generation from pumqry: lengths are not always right, so calculate it for now
+        try:
+            length = _format_to_length(tel_def.format) + SIZEOF_HEADER_FOOTER
+        except ValueError:
+            length = 77     # SUP FW version string length (cannot know size of strings)
+
         # Send the telemetry request, and parse the response.
         cmd_str = f"{cmd_str}:TEL? {tel_def.idx}\n"
         self.i2c_master.write(module_def.address, cmd_str.encode('ascii'))
         time.sleep(self.request_delay)
-        b = self.i2c_master.read(module_def.address, tel_def.telemetry_length)
+        b = self.i2c_master.read(module_def.address, length)
         return parse_telemetry(b, tel_def)
