@@ -114,7 +114,7 @@ _data_type_supmcu_fmt = {
 
 
 @dataclass
-class SupMCUTelemetryDefinition(object):
+class SupMCUTelemetryDefinition():
     """A SupMCU Telemetry definition consists of the name, length and format of the returned data."""
     name: str
     telemetry_length: int
@@ -132,7 +132,7 @@ class SupMCUCommand:
 
 
 @dataclass
-class SupMCUModuleDefinition(object):
+class SupMCUModuleDefinition():
     """A SupMCU Module definition consists of the name, address, cmd_name, SupMCU Telemetry, module telemetry, and
     SupMCU commands and module commands."""
     name: str
@@ -144,33 +144,34 @@ class SupMCUModuleDefinition(object):
 
 
 @dataclass
-class TelemetryDataItem(object):
+class TelemetryDataItem():
     """A single data item from a telemetry request."""
     data_type: DataType
     value: Any
     string_value: str
 
     def set_value(self, val: Any):
+        """Sets data item value and string value"""
         self.value = val
         self.string_value = str(val) if self.data_type not in (DataType.Hex8, DataType.Hex16) else str(hex(val))
 
 
 @dataclass
-class SupMCUHDR(object):
+class SupMCUHDR():
     """The SupMCU Telemetry header with timestamp and is_ready information."""
     ready: bool
     timestamp: int
 
 
 @dataclass
-class SupMCUTelemetry(object):
+class SupMCUTelemetry():
     """A SupMCU Telemetry request response. Consists of zero or more TelemetryDataItems."""
     header: SupMCUHDR
     items: List[TelemetryDataItem]
 
 
 @dataclass
-class SupMCUCommandResponse(object):
+class SupMCUCommandResponse():
     """A SupMCU Command request response. Consists of a header and string representing the command name."""
     header: SupMCUHDR
     command_name: str
